@@ -88,7 +88,9 @@ class StorageAccountSessionInterface(SessionInterface):
             self.storage.write(session.sid, dict(session), encryption_key)
         httponly = True
         secure = self.get_cookie_secure(app)
-        samesite = 'Strict'
+        samesite = self.get_cookie_samesite(app)
+        if samesite is None:
+            samesite = 'Lax'
         expires = self.get_expiration_time(app, session)
         response.set_cookie(app.session_cookie_name, session.sid, expires=expires, httponly=httponly, domain=domain,
                             path=path, secure=secure, samesite=samesite)
